@@ -148,14 +148,14 @@ crashreport_check (TrayApplet *ta)
    if (g_file_test(CRASHREPORT_AUTOREPORT, G_FILE_TEST_EXISTS))
       return FALSE;
    
-   // if whoopsie is installed, by disabled, don't do anything
+   // if whoopsie is installed, but disabled, don't do anything
    if (g_file_test(CRASHREPORT_WHOOPSIE_EXEC, G_FILE_TEST_IS_EXECUTABLE)) {
       int exitcode;
-      gchar *argv[] = { "/bin/systemctl", "is-enabled", "-q", CRASHREPORT_WHOOPSIE_SERVICE, NULL };
+      gchar *argv[] = { "/bin/systemctl", "is-enabled", "-q", CRASHREPORT_WHOOPSIE_UNIT, NULL };
       if (g_spawn_sync(NULL, argv, NULL, G_SPAWN_STDOUT_TO_DEV_NULL|G_SPAWN_STDERR_TO_DEV_NULL,
                       NULL, NULL, NULL, NULL, &exitcode, NULL)) {
          if (exitcode != 0) {
-            g_debug("whoopsie disabled, not displaying crashes");
+            g_debug("whoopsie.path disabled, not displaying crashes");
             return FALSE;
          }
       }
