@@ -80,7 +80,6 @@
 #endif
 
 void invoke_with_pkexec(const gchar *cmd);
-void invoke(const gchar *cmd, const gchar *desktop, gboolean with_pkexec);
 gboolean in_admin_group(void);
 time_t dpkg_info_time_since_update(void);
 void dpkg_info_updated(void);
@@ -105,6 +104,7 @@ struct _TrayApplet
 struct _UpgradeNotifier
 {
    GSettings *settings;
+   GSList *file_monitors;
 
    TrayApplet *update;
    TrayApplet *reboot;
