@@ -15,6 +15,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+#include "notify-utils.h"
 #include "update-notifier.h"
 #include "update.h"
 #include "trayappletui.h"
@@ -22,25 +23,28 @@
 #define UPGRADE_CHECKER PACKAGE_LIB_DIR"/update-notifier/apt-check"
 #define PACKAGE_SYSTEM_LOCKED PACKAGE_LIB_DIR"/update-notifier/package-system-locked"
 
-// command, description, desktopfile, needs_pkexec
-const char* actions[][4] = {
-   { "/usr/lib/update-notifier/backend_helper.py show_updates",
-     N_("Show updates"), 
-     "/usr/share/applications/update-manager.desktop", 
-     GINT_TO_POINTER(FALSE) },
-   { "/usr/lib/update-notifier/backend_helper.py install_all_updates",
-     N_("Install all updates"), "/usr/share/applications/synaptic.desktop", 
-     GINT_TO_POINTER(FALSE)
+typedef struct {
+   const char *id;         // the action identifier
+   const char *command;    // the command to execude
+   const char *desc;       // the user-visible description
+} action_t;
+
+static action_t actions[] = {
+   {
+      "install-all",
+      "/usr/bin/update-manager --no-update --install-all",
+      N_("Install Now"),
+   },
+   {
+      "show-updates",
+      "/usr/bin/update-manager --no-update",
+      N_("Show Updates"),
    },
-   { "/usr/lib/update-notifier/backend_helper.py check_updates",
-     N_("Check for updates"), "/usr/share/applications/synaptic.desktop", 
-     GINT_TO_POINTER(FALSE) },
-   { "/usr/lib/update-notifier/backend_helper.py start_packagemanager",
-     N_("Start package manager"), "/usr/share/applications/synaptic.desktop",
-     GINT_TO_POINTER(FALSE)},
-   { NULL, NULL, NULL }
 };
 
+#define DEFAULT_ACTION_IDX 1
+G_STATIC_ASSERT (DEFAULT_ACTION_IDX < G_N_ELEMENTS (actions));
+
 enum { 
    NOTIFICATION_DEFAULT, 
    NOTIFICATION_IGNORE, 
@@ -56,19 +60,43 @@ g_debug_update(const char *msg, ...)
    va_end(va);
 }
 
+static void
+launch_update_action (action_t *action, TrayApplet *ta, GAppLaunchContext *context) {
+    UpdateTrayAppletPrivate *priv = ta->user_data;
+    g_autoptr (GAppInfo) app_info = NULL;
+    g_autoptr (GError) error = NULL;
+
+    app_info = g_app_info_create_from_commandline (action->command,
+                                                   g_app_info_get_name (G_APP_INFO (priv->software_updater_app)),
+                                                   G_APP_INFO_CREATE_SUPPORTS_STARTUP_NOTIFICATION,
+                                                   NULL);
+    g_return_if_fail (app_info != NULL);
+
+    g_app_launch_context_setenv (context, "GIO_LAUNCHED_DESKTOP_FILE",
+                                 g_desktop_app_info_get_filename (priv->software_updater_app));
+    if (!g_app_info_launch (app_info, NULL, context, &error)) {
+        g_warning ("Failed to launch %s: %s",
+                   g_app_info_get_id (G_APP_INFO (priv->software_updater_app)),
+                   error->message);
+    }
+}
+
 #ifndef HAVE_APP_INDICATOR
 static gboolean
 gtk_status_icon_click_activate_cb (GtkWidget *widget, 
 	     TrayApplet *ta)
 {
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
-   int index = priv->apt_is_running ? 3 : 0;
-   
+   g_autoptr (GAppLaunchContext) context = NULL;
+
    // on double click we get two activate signals, so slow down things
    // here a bit to avoid double starting
    static time_t last_action = 0;
-   if (time(NULL) - last_action > 1) 
-      invoke (actions[index][0], actions[index][2], (long)actions[index][3]);
+   if (time(NULL) - last_action < 1)
+      return TRUE;
+
+   context = g_app_launch_context_new ();
+   launch_update_action (&actions[DEFAULT_ACTION_IDX], ta, context);
    last_action = time(NULL);
    return TRUE;
 }
@@ -90,18 +118,27 @@ update_trayicon_update_tooltip (TrayApplet *ta, int num_upgrades)
 
 
 static void 
-cb_action(GObject *self, void *user_data __attribute__ ((__unused__)))
+cb_action(GObject *self, void *user_data)
 {
+   TrayApplet *ta = (TrayApplet*)user_data;
+   UpdateTrayAppletPrivate *priv = ta->user_data;
+   g_autoptr (GAppLaunchContext) context = NULL;
+
    int i = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(self), "action"));
-   invoke (actions[i][0], _(actions[i][2]), (long)actions[i][3]);
+   context = g_app_launch_context_new ();
+   launch_update_action (&actions[i], ta, context);
 }
 
 static void 
 cb_preferences(GObject *self, void *user_data)
 {
-   invoke("/usr/bin/software-properties-gtk",
-          "/usr/share/applications/software-properties.desktop",
-          FALSE);    
+   TrayApplet *ta = user_data;
+   UpdateTrayAppletPrivate *priv = ta->user_data;
+   g_autoptr (GAppLaunchContext) context = g_app_launch_context_new ();
+   g_autoptr (GError) error = NULL;
+
+   if (!g_app_info_launch (G_APP_INFO (priv->software_properties_app), NULL, context, &error))
+      g_warning ("failed to launch preferences: %s", error->message);
 }
 
 static void 
@@ -125,15 +162,14 @@ cb_toggled_show_notifications(GObject *self, void *data)
 static void
 update_trayicon_create_menu(TrayApplet *ta)
 {
+	UpdateTrayAppletPrivate *priv = ta->user_data;
 	GtkWidget *menuitem;
 	int i;
 
 	ta->menu = gtk_menu_new ();
 
-	for(i=0;actions[i][0]!=NULL;i++) {
-	    if (!g_file_test(actions[i][2], G_FILE_TEST_EXISTS))
-	        continue;
-	   menuitem = gtk_menu_item_new_with_label (_(actions[i][1]));
+	for (i = 0; i < G_N_ELEMENTS (actions); i++) {
+	   menuitem = gtk_menu_item_new_with_label (_(actions[i].desc));
 
 	   gtk_menu_shell_append (GTK_MENU_SHELL (ta->menu), menuitem);
 	   g_object_set_data(G_OBJECT(menuitem), "action", GINT_TO_POINTER(i));
@@ -151,13 +187,13 @@ update_trayicon_create_menu(TrayApplet *ta)
 	gtk_menu_shell_append (GTK_MENU_SHELL (ta->menu), menuitem);
 	g_signal_connect(G_OBJECT(menuitem), "toggled", 
 			 G_CALLBACK(cb_toggled_show_notifications), ta);
-	
 
-	menuitem = gtk_image_menu_item_new_from_stock (GTK_STOCK_PREFERENCES, NULL);
-	if (g_file_test("/usr/bin/software-properties-gtk", G_FILE_TEST_EXISTS))
-	    gtk_menu_shell_append (GTK_MENU_SHELL (ta->menu), menuitem);
-	g_signal_connect(G_OBJECT(menuitem), "activate", 
-			 G_CALLBACK(cb_preferences), (void*)ta);
+	if (priv->software_properties_app) {
+	   menuitem = gtk_image_menu_item_new_from_stock (GTK_STOCK_PREFERENCES, NULL);
+	   gtk_menu_shell_append (GTK_MENU_SHELL (ta->menu), menuitem);
+	   g_signal_connect(G_OBJECT(menuitem), "activate",
+	                    G_CALLBACK(cb_preferences), ta);
+	}
 
 	gtk_widget_show_all (ta->menu);
 }
@@ -174,9 +210,6 @@ update_apt_is_running(TrayApplet *ta, gboolean is_running)
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
    priv->apt_is_running = is_running;
 
-   // everybody wants auto-launch mode
-   return;
-
    if(is_running) {
 #ifdef HAVE_APP_INDICATOR
       // we can't do fancy stuff like the gray-out with app-indicator,
@@ -214,53 +247,95 @@ update_apt_is_running(TrayApplet *ta, gboolean is_running)
    }
 }
 
+static void
+on_notification_action(NotifyNotification *notification, char* id, gpointer user_data)
+{
+    TrayApplet *ta = user_data;
+    UpdateTrayAppletPrivate *priv = ta->user_data;
+    g_autoptr (GAppLaunchContext) context = NULL;
+    const char* activation_token;
+    int action_idx = DEFAULT_ACTION_IDX;
+    gboolean found = FALSE;
+
+    g_return_if_fail (ta != NULL);
+
+    for (int i = 0; i < G_N_ELEMENTS (actions); i++) {
+        if (g_str_equal (id, actions[i].id)) {
+            action_idx = i;
+            found = TRUE;
+            break;
+        }
+    }
+
+    if (!found && !g_str_equal (id, "default"))
+        g_warning ("received bad notification action; fallback to default");
+
+    context = notification_app_launch_context_new (notification);
+    launch_update_action (&actions[action_idx], ta, context);
+}
+
 // actually show the notification 
 static gint 
 show_notification(gpointer user_data)
 {
    TrayApplet *ta = (TrayApplet *)user_data;
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
+   g_autoptr (GSettings) settings = NULL;
+   g_autoptr (NotifyNotification) n = NULL;
+   g_autofree char *title = NULL;
+   g_autofree char *desc = NULL;
+   g_autofree char *app_icon_name = NULL;
+   g_autofree char *app_id_no_suffix = NULL;
+   const char *app_name;
+   const char *app_id;
 
    // apt is running, no point in showing a notification
    if(priv->apt_is_running) 
-      return TRUE;
+      return G_SOURCE_CONTINUE;
 
    // check if the update-icon is still visible (in the delay time a 
    // update may already have been performed)
    if(!tray_applet_ui_get_visible(ta))
-      return FALSE;
+      return G_SOURCE_REMOVE;
+
+   app_name = g_app_info_get_name (G_APP_INFO (priv->software_updater_app));
+   app_id = g_app_info_get_id (G_APP_INFO (priv->software_updater_app));
+   app_icon_name = g_desktop_app_info_get_string (priv->software_updater_app,
+                                                  G_KEY_FILE_DESKTOP_KEY_ICON);
+
+   g_return_val_if_fail (app_name && app_id, G_SOURCE_REMOVE);
 
    // now show a notification handle 
-   gchar *updates;
-   updates = g_strdup_printf(ngettext("There is %i update available. "
-				      "Click on the notification "
-				      "icon to show the "
-				      "available update.",
-				      "There are %i updates available. "
-				      "Click on the notification "
-				      "icon to show the "
-				      "available updates.",
-				      priv->num_upgrades), 
-			     priv->num_upgrades);
-   NotifyNotification *n = notify_notification_new(
-			      _("Software updates available"),
-			      updates,
-			      NULL);
+   title = g_strdup_printf(ngettext("%i Update Available",
+                                    "%i Updates Available",
+                                     priv->num_upgrades),\
+                                     priv->num_upgrades);
 
-   GdkPixbuf* pix= gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), 
-					    GTK_STOCK_DIALOG_INFO, 48,0,NULL);
-   notify_notification_set_icon_from_pixbuf (n, pix);
-   g_object_unref(pix);
+   /* TRANSLATORS: %s is the already translated name for the update-manager.desktop application */
+   desc = g_strdup_printf(_("You can review them in the %s."), app_name);
+
+   app_id_no_suffix = g_strndup (app_id, strlen (app_id) - strlen (".desktop"));
+   n = notify_notification_new (title, desc, NULL);
+   notify_notification_set_app_icon (n, app_icon_name);
+   notify_notification_set_hint (n, "desktop-entry", g_variant_new_string (app_id_no_suffix));
    notify_notification_set_timeout (n, 60*1000);
+   notify_notification_add_action (n, "default", _(actions[DEFAULT_ACTION_IDX].desc),
+                                   on_notification_action, ta, NULL);
+   for (int i = 0; i < G_N_ELEMENTS (actions); i++) {
+      notify_notification_add_action (n, actions[i].id, _(actions[i].desc),
+                                      on_notification_action, ta, NULL);
+   }
    notify_notification_show(n, NULL);
    // save the notification handle
    if (priv->active_notification)
       g_object_unref(priv->active_notification);
-   priv->active_notification = n;
+   priv->active_notification = g_steal_pointer (&n);
+
+   settings = g_settings_new (SETTINGS_UM_SCHEMA);
+   g_settings_set_int64 (settings, SETTINGS_UM_KEY_LAST_LAUNCH, time(NULL));
 
    // remove this from the timeout now
-   g_free(updates);
-   return FALSE;
+   return G_SOURCE_REMOVE;
 }
 
 static void 
@@ -399,8 +474,8 @@ auto_launch_security_now(UpdateTrayAppletPrivate *priv,
 			 time_t last_launch)
 {
 
-   // no security updates and no reboot pending
-   if ((priv->num_security == 0) && !priv->reboot_pending)
+   // no security updates
+   if (priv->num_security == 0)
       return FALSE;
 	 
    // security updates, but already launched recently
@@ -531,26 +606,6 @@ auto_launch_now (TrayApplet *ta)
    return FALSE;
 }
 
-static void
-launch_update_manager (GPid pid,
-                       gint status,
-                       gpointer user_data G_GNUC_UNUSED)
-{
-   g_autoptr(GError) error = NULL;
-
-   g_spawn_check_exit_status (status, &error);
-
-   /* list-oem-metapackages exited abnormally */
-   if (error != NULL)
-   {
-      g_printerr ("list-oem-metapackages exited abnormally: %s\n", error->message);
-      return;
-   }
-
-   g_spawn_command_line_async("nice ionice -c3 update-manager "
-                              "--no-update --no-focus-on-map", NULL);
-}
-
 gboolean
 update_check (TrayApplet *ta)
 {
@@ -562,7 +617,6 @@ update_check (TrayApplet *ta)
 
    priv->num_upgrades = 0;
    priv->num_security = 0;
-   priv->reboot_pending = FALSE;
    int exit_status = 0;
    GError *error = NULL;
 
@@ -571,7 +625,6 @@ update_check (TrayApplet *ta)
 		   UPGRADE_CHECKER, 
 		   NULL };
    char *ret;
-   struct stat buf;
 
    if(g_spawn_sync(NULL, cmd, NULL,  
 		   G_SPAWN_STDOUT_TO_DEV_NULL, 
@@ -629,13 +682,9 @@ update_check (TrayApplet *ta)
    
    g_debug_update("%s returned %i (security: %i)", UPGRADE_CHECKER, priv->num_upgrades, priv->num_security);
 
-   if (stat("/run/reboot-required", &buf) == 0) {
-      priv->reboot_pending = TRUE;
-      g_debug_update("A reboot is currently pending.");
-   }
-
-   if ((priv->num_upgrades == 0) && !priv->reboot_pending) {
+   if (priv->num_upgrades == 0) {
       // check if the periodic file is very old
+      struct stat buf;
       if ((stat("/var/lib/apt/periodic/update-success-stamp", &buf) == 0) &&
 	  (time(NULL) - buf.st_mtime > OUTDATED_NAG_AGE) ) 
 	 g_timeout_add_seconds(OUTDATED_NAG_WAIT, (GSourceFunc)outdated_nag, ta);
@@ -649,45 +698,21 @@ update_check (TrayApplet *ta)
    } 
 
    if (priv->num_security == 0)
-      ta->name = "software-update-available";
+      ta->name = "software-update-available-symbolic";
    else
-      ta->name = "software-update-urgent";
+      ta->name = "software-update-urgent-symbolic";
    tray_applet_ui_set_icon(ta, ta->name);
 
    // update the tooltip
    update_trayicon_update_tooltip(ta, priv->num_upgrades);
 
-   tray_applet_ui_set_visible(ta, FALSE);
-   if (auto_launch_now(ta))
+   if (auto_launch_now(ta) &&
+       !g_settings_get_boolean(ta->un->settings, SETTINGS_KEY_NO_UPDATE_NOTIFICATIONS))
    {
-      g_autoptr(GError) error = NULL;
-      g_autofree gchar *list_oem_metapackages = NULL;
-      GPid pid;
-      g_auto(GStrv) argv = g_new0(char *, 2);
-
-      argv[0] = g_build_filename (PACKAGE_LIB_DIR,
-                                  "update-notifier",
-                                  "list-oem-metapackages",
-                                  NULL);
-
-      g_spawn_async (NULL, /* working_directory */
-                     argv,
-                     NULL, /* envp */
-                     G_SPAWN_DO_NOT_REAP_CHILD,
-                     NULL, /* child_setup */
-                     NULL, /* user_data */
-                     &pid,
-                     &error);
-
-      if (error != NULL)
-      {
-         g_printerr("Failed to spawn ‘list-oem-metapackages’: %s\n", error->message);
-         return FALSE;
-      }
-
-      g_child_watch_add (pid, launch_update_manager, NULL);
+      // show the notification with some delay. otherwise on a login
+      // the origin of the window is 0,0 and that looks ugly
+      g_timeout_add_seconds(5, show_notification, ta);
    }
-   return TRUE;
 
    // if we are already visible, skip the rest
    if(tray_applet_ui_get_visible (ta))
@@ -695,25 +720,19 @@ update_check (TrayApplet *ta)
 
    // show the icon
    tray_applet_ui_set_visible(ta, TRUE);
-   
-   // the user does not no notification messages
-   if(g_settings_get_boolean(ta->un->settings,
-                             SETTINGS_KEY_NO_UPDATE_NOTIFICATIONS))
-      return TRUE;
-
-   // show the notification with some delay. otherwise on a login
-   // the origin of the window is 0,0 and that looks ugly
-   g_timeout_add_seconds(5, show_notification, ta);
 
    return TRUE;
 }
 
-
 void 
-update_tray_icon_init(TrayApplet *ta)
+update_tray_icon_init(TrayApplet *ta, GDesktopAppInfo *software_updater_app)
 {
    // create the private data struct
    UpdateTrayAppletPrivate *priv = g_new0(UpdateTrayAppletPrivate, 1);
+
+   priv->software_updater_app = g_object_ref (software_updater_app);
+   priv->software_properties_app = g_desktop_app_info_new ("software-properties-gtk.desktop");
+
    priv->apt_is_running = FALSE;
    priv->active_notification = NULL;
    ta->user_data = priv;
