@@ -29,15 +29,15 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=1,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 0 updates can be applied immediately.
 
-                1 additional security update can be applied with UA Infra: ESM
-                Learn more about enabling UA Infra: ESM service for Ubuntu 16.04 at
+                1 additional security update can be applied with ESM Infra.
+                Learn more about enabling ESM Infra service for Ubuntu 16.04 at
                 https://ubuntu.com/16-04
                 """))
 
@@ -52,17 +52,17 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=23,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 15 updates can be applied immediately.
                 1 of these updates is a standard security update.
                 To see these additional updates run: apt list --upgradable
 
-                23 additional security updates can be applied with UA Infra: ESM
-                Learn more about enabling UA Infra: ESM service for Ubuntu 18.04 at
+                23 additional security updates can be applied with ESM Infra.
+                Learn more about enabling ESM Infra service for Ubuntu 18.04 at
                 https://ubuntu.com/18-04
                 """))
 
@@ -76,17 +76,17 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 15 updates can be applied immediately.
                 7 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
 
-                Enable UA Infra: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Infra to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=True)
@@ -99,16 +99,16 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 15 updates can be applied immediately.
                 To see these additional updates run: apt list --upgradable
 
-                Enable UA Infra: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Infra to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=True)
@@ -121,15 +121,15 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 0 updates can be applied immediately.
 
-                Enable UA Infra: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Infra to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=True)
@@ -142,13 +142,13 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=13, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is enabled.
+                Expanded Security Maintenance for Infrastructure is enabled.
 
                 35 updates can be applied immediately.
-                13 of these updates are UA Infra: ESM security updates.
+                13 of these updates are ESM Infra security updates.
                 To see these additional updates run: apt list --upgradable
                 """))
 
@@ -162,13 +162,13 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=13, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is enabled.
+                Expanded Security Maintenance for Infrastructure is enabled.
 
                 47 updates can be applied immediately.
-                13 of these updates are UA Infra: ESM security updates.
+                13 of these updates are ESM Infra security updates.
                 7 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
                 """))
@@ -183,10 +183,10 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=True, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=10),
+                        disabled_esm_apps_updates=10, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is enabled.
+                Expanded Security Maintenance for Infrastructure is enabled.
 
                 0 updates can be applied immediately.
                 """))
@@ -201,14 +201,14 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=15, esm_apps_updates=15,
                         have_esm_infra=True, have_esm_apps=True,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """
-                UA Infra: Extended Security Maintenance (ESM) is enabled.
+                Expanded Security Maintenance for Infrastructure is enabled.
 
                 30 updates can be applied immediately.
-                15 of these updates are UA Infra: ESM security updates.
-                15 of these updates are UA Apps: ESM security updates.
+                15 of these updates are ESM Infra security updates.
+                15 of these updates are ESM Apps security updates.
                 To see these additional updates run: apt list --upgradable
                 """).lstrip())
 
@@ -222,18 +222,18 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=15,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 30 updates can be applied immediately.
-                15 of these updates are UA Apps: ESM security updates.
+                15 of these updates are ESM Apps security updates.
                 12 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
 
-                Enable UA Infra: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Infra to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """).lstrip())
 
     @mock.patch("apt_check.get_distro_version", return_value="16.04")
@@ -247,18 +247,18 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=1,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 30 updates can be applied immediately.
-                1 of these updates is a UA Apps: ESM security update.
+                1 of these updates is an ESM Apps security update.
                 15 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
 
-                40 additional security updates can be applied with UA Infra: ESM
-                Learn more about enabling UA Infra: ESM service for Ubuntu 16.04 at
+                40 additional security updates can be applied with ESM Infra.
+                Learn more about enabling ESM Infra service for Ubuntu 16.04 at
                 https://ubuntu.com/16-04
                 """).lstrip())
 
@@ -272,13 +272,13 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=1,
                         have_esm_infra=False, have_esm_apps=True,
                         disabled_esm_infra_updates=40,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """
-                UA Apps: Extended Security Maintenance (ESM) is enabled.
+                Expanded Security Maintenance for Applications is enabled.
 
                 30 updates can be applied immediately.
-                1 of these updates is a UA Apps: ESM security update.
+                1 of these updates is an ESM Apps security update.
                 15 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
                 """).lstrip())
@@ -293,17 +293,17 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40),
+                        disabled_esm_apps_updates=40, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Infra: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Infrastructure is not enabled.
 
                 30 updates can be applied immediately.
                 18 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
 
-                Enable UA Infra: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Infra to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=True)
@@ -316,7 +316,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -334,7 +334,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -352,7 +352,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40),
+                        disabled_esm_apps_updates=40, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -375,7 +375,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=40),
+                        disabled_esm_apps_updates=40, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 30 updates can be applied immediately.
@@ -393,17 +393,17 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=10,
-                        disabled_esm_apps_updates=40),
+                        disabled_esm_apps_updates=40, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Apps: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Applications is not enabled.
 
                 30 updates can be applied immediately.
                 18 of these updates are standard security updates.
                 To see these additional updates run: apt list --upgradable
 
-                40 additional security updates can be applied with UA Apps: ESM
-                Learn more about enabling UA Apps: ESM service at https://ubuntu.com/esm
+                40 additional security updates can be applied with ESM Apps.
+                Learn more about enabling ESM Apps service at https://ubuntu.com/esm
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=False)
@@ -416,7 +416,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 0 updates can be applied immediately.
@@ -432,7 +432,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -449,7 +449,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -467,7 +467,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 0 updates can be applied immediately.
@@ -483,15 +483,15 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=False, have_esm_apps=False,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
-                UA Apps: Extended Security Maintenance (ESM) is not enabled.
+                Expanded Security Maintenance for Applications is not enabled.
 
                 0 updates can be applied immediately.
 
-                Enable UA Apps: ESM to receive additional future security updates.
-                See https://ubuntu.com/esm or run: sudo ua status
+                Enable ESM Apps to receive additional future security updates.
+                See https://ubuntu.com/esm or run: sudo pro status
                 """))
 
     @mock.patch("apt_check.is_lts_distro", return_value=True)
@@ -504,7 +504,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -521,7 +521,7 @@ class TestMotd(unittest.TestCase):
                         esm_infra_updates=0, esm_apps_updates=0,
                         have_esm_infra=None, have_esm_apps=None,
                         disabled_esm_infra_updates=0,
-                        disabled_esm_apps_updates=0),
+                        disabled_esm_apps_updates=0, hide_esm_messages=False),
             textwrap.dedent(
                 """\
                 1 update can be applied immediately.
@@ -529,6 +529,94 @@ class TestMotd(unittest.TestCase):
                 To see these additional updates run: apt list --upgradable
                 """))
 
+    @mock.patch("apt_check.is_lts_distro", return_value=True)
+    @mock.patch("apt_check.is_esm_distro", return_value=False)
+    def test_message_no_upgrades_lts_distro_with_esm_sources_hide_esm(
+        self, _m_is_esm, _m_is_lts
+    ):
+        self.assertEqual(
+            get_message(upgrades=0, security_updates=0,
+                        esm_infra_updates=0, esm_apps_updates=0,
+                        have_esm_infra=False, have_esm_apps=False,
+                        disabled_esm_infra_updates=0,
+                        disabled_esm_apps_updates=0, hide_esm_messages=True),
+            textwrap.dedent(
+                """\
+                0 updates can be applied immediately.
+                """))
+
+    @mock.patch("apt_check.is_lts_distro", return_value=True)
+    @mock.patch("apt_check.is_esm_distro", return_value=False)
+    def test_message_for_lts_distro_not_in_esm_mode_yet_hide_esm(
+        self, _m_is_esm, _m_is_lts
+    ):
+        self.assertEqual(
+            get_message(upgrades=30, security_updates=18,
+                        esm_infra_updates=0, esm_apps_updates=0,
+                        have_esm_infra=False, have_esm_apps=False,
+                        disabled_esm_infra_updates=10,
+                        disabled_esm_apps_updates=40, hide_esm_messages=True),
+            textwrap.dedent(
+                """\
+                30 updates can be applied immediately.
+                18 of these updates are standard security updates.
+                To see these additional updates run: apt list --upgradable
+                """))
+
+    @mock.patch("apt_check.is_lts_distro", return_value=True)
+    @mock.patch("apt_check.is_esm_distro", return_value=False)
+    def test_esm_infra_disabled_wih_pkgs_and_esm_apps_on_lts_distro_hide_esm(
+        self, _m_esm_distro, _m_is_lts
+    ):
+        self.assertEqual(
+            get_message(upgrades=30, security_updates=15,
+                        esm_infra_updates=0, esm_apps_updates=1,
+                        have_esm_infra=False, have_esm_apps=True,
+                        disabled_esm_infra_updates=40,
+                        disabled_esm_apps_updates=0, hide_esm_messages=True),
+            textwrap.dedent(
+                """
+                30 updates can be applied immediately.
+                15 of these updates are standard security updates.
+                To see these additional updates run: apt list --upgradable
+                """).lstrip())
+
+    @mock.patch("apt_check.get_distro_version", return_value="16.04")
+    @mock.patch("apt_check.is_lts_distro", return_value=True)
+    @mock.patch("apt_check.is_esm_distro", return_value=True)
+    def test_esm_infra_disabled_wih_pkgs_and_esm_apps_enabled_hide_esm(
+        self, _m_esm_distro, _m_is_lts, _m_distro_version
+    ):
+        self.assertEqual(
+            get_message(upgrades=30, security_updates=15,
+                        esm_infra_updates=0, esm_apps_updates=1,
+                        have_esm_infra=False, have_esm_apps=True,
+                        disabled_esm_infra_updates=40,
+                        disabled_esm_apps_updates=0, hide_esm_messages=True),
+            textwrap.dedent(
+                """
+                30 updates can be applied immediately.
+                15 of these updates are standard security updates.
+                To see these additional updates run: apt list --upgradable
+                """).lstrip())
+
+    @mock.patch("apt_check.is_lts_distro", return_value=True)
+    @mock.patch("apt_check.is_esm_distro", return_value=True)
+    def test_esm_infra_and_esm_apps_enabled_hide_esm(
+        self, _m_esm_distro, _m_is_lts
+    ):
+        self.assertEqual(
+            get_message(upgrades=30, security_updates=0,
+                        esm_infra_updates=15, esm_apps_updates=15,
+                        have_esm_infra=True, have_esm_apps=True,
+                        disabled_esm_infra_updates=0,
+                        disabled_esm_apps_updates=0, hide_esm_messages=True),
+            textwrap.dedent(
+                """
+                30 updates can be applied immediately.
+                To see these additional updates run: apt list --upgradable
+                """).lstrip())
+
 
 class TestGetDistro(unittest.TestCase):
     @mock.patch("os.path.exists", return_value=True)
@@ -555,8 +643,7 @@ class TestGetDistro(unittest.TestCase):
             ] == m_open.call_args_list
 
     @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("subprocess.check_output")
-    def test_get_distro_no_ubuntu_codename(self, m_check_output, _m_path):
+    def test_get_distro_no_ubuntu_codename(self, _m_path):
         read_data = (
             "NAME=Ubuntu\n"
             "VERSION=version\n"
@@ -565,39 +652,35 @@ class TestGetDistro(unittest.TestCase):
             "PRETTY_NAME=Ubuntu XX.XX\n"
             "VERSION_ID=XX.XX\n"
         )
-        expected_value = "codename"
-        m_check_output.return_value = expected_value
+        expected_msg = (
+            "Could not find UBUNTU_CODENAME in "
+        ) + apt_check.OS_RELEASE_PATH
 
         with mock.patch(
             "builtins.open",
             mock.mock_open(read_data=read_data)
         ) as m_open:
-            assert expected_value == apt_check.get_distro()
+            with self.assertRaises(Exception) as context:
+                apt_check.get_distro()
+
+            assert expected_msg == str(context.exception)
+
             assert 1 == _m_path.call_count
             assert [
                 mock.call(apt_check.OS_RELEASE_PATH)
             ] == m_open.call_args_list
-            assert [
-                mock.call(
-                    ["lsb_release", "-c", "-s"],
-                    universal_newlines=True
-                )
-            ] == m_check_output.call_args_list
 
     @mock.patch("os.path.exists", return_value=False)
-    @mock.patch("subprocess.check_output")
-    def test_get_distro_no_os_release(self, m_check_output, _m_path):
-        expected_value = "codename"
-        m_check_output.return_value = expected_value
+    def test_get_distro_no_os_release(self, _m_path):
+        expected_msg = "File {} was not found on the system".format(
+            apt_check.OS_RELEASE_PATH
+        )
 
-        assert expected_value == apt_check.get_distro()
+        with self.assertRaises(Exception) as context:
+            apt_check.get_distro()
+
+        assert expected_msg == str(context.exception)
         assert 1 == _m_path.call_count
-        assert [
-            mock.call(
-                ["lsb_release", "-c", "-s"],
-                universal_newlines=True
-            )
-        ] == m_check_output.call_args_list
 
 
 class TestDistroVersion(unittest.TestCase):
@@ -624,53 +707,6 @@ class TestDistroVersion(unittest.TestCase):
                 mock.call(apt_check.OS_RELEASE_PATH)
             ] == m_open.call_args_list
 
-    @mock.patch("os.path.exists", return_value=True)
-    @mock.patch("subprocess.check_output")
-    def test_get_distro_version_no_ubuntu_version(
-        self, m_check_output, _m_path
-    ):
-        read_data = (
-            "UBUNTU_CODENAME=test\n"
-            "NAME=Ubuntu\n"
-            "VERSION=version\n"
-            "ID=ubuntu\n"
-            "ID_LIKE=debian\n"
-            "PRETTY_NAME=Ubuntu XX.XX\n"
-        )
-        expected_value = "XX.XX"
-        m_check_output.return_value = expected_value
-
-        with mock.patch(
-            "builtins.open",
-            mock.mock_open(read_data=read_data)
-        ) as m_open:
-            assert expected_value == apt_check.get_distro_version()
-            assert 1 == _m_path.call_count
-            assert [
-                mock.call(apt_check.OS_RELEASE_PATH)
-            ] == m_open.call_args_list
-            assert [
-                mock.call(
-                    ["lsb_release", "-r", "-s"],
-                    universal_newlines=True
-                )
-            ] == m_check_output.call_args_list
-
-    @mock.patch("os.path.exists", return_value=False)
-    @mock.patch("subprocess.check_output")
-    def test_get_distro_version_no_os_release(self, m_check_output, _m_path):
-        expected_value = "codename"
-        m_check_output.return_value = expected_value
-
-        assert expected_value == apt_check.get_distro_version()
-        assert 1 == _m_path.call_count
-        assert [
-            mock.call(
-                ["lsb_release", "-r", "-s"],
-                universal_newlines=True
-            )
-        ] == m_check_output.call_args_list
-
 
 if __name__ == "__main__":
     import logging
